@@ -348,9 +348,9 @@ public class ProxyFactory {
         if (thisClass != null && value != null)
             try {
                 Field f = thisClass.getField(fieldName);
-                f.setAccessible(true);
+                SecurityActions.setAccessible(f, true);
                 f.set(null, value);
-                f.setAccessible(false);
+                SecurityActions.setAccessible(f, false);
             }
             catch (Exception e) {
                 throw new RuntimeException(e);
@@ -586,6 +586,7 @@ public class ProxyFactory {
         finfo.setAccessFlags(AccessFlag.PRIVATE | AccessFlag.STATIC);
         cf.addField(finfo);
         MethodInfo minfo = new MethodInfo(cp, "<clinit>", "()V");
+        minfo.setAccessFlags(AccessFlag.STATIC);
         Bytecode code = new Bytecode(cp, 0, 0);
         code.addIconst(size * 2);
         code.addAnewarray("java.lang.reflect.Method");
@@ -658,7 +659,7 @@ public class ProxyFactory {
     private void makeConstructors(String thisClassName, ClassFile cf,
             ConstPool cp, String classname) throws CannotCompileException
     {
-        Constructor[] cons = superClass.getDeclaredConstructors();
+        Constructor[] cons = SecurityActions.getDeclaredConstructors(superClass);
         for (int i = 0; i < cons.length; i++) {
             Constructor c = cons[i];
             int mod = c.getModifiers();
@@ -740,7 +741,7 @@ public class ProxyFactory {
         if (parent != null)
             getMethods(hash, parent);
 
-        Method[] methods = clazz.getDeclaredMethods();
+        Method[] methods = SecurityActions.getDeclaredMethods(clazz);
         for (int i = 0; i < methods.length; i++)
             if (!Modifier.isPrivate(methods[i].getModifiers())) {
                 Method m = methods[i];
